Struct sdl2::rect::Point
[−]
[src]
pub struct Point {
// some fields omitted
}Immutable point type, consisting of x and y.
pub struct Point {
// some fields omitted
}Immutable point type, consisting of x and y.
impl Pointfn raw(&self) -> *const SDL_Pointfn raw_slice(slice: &[Point]) -> *const SDL_Pointfn from_ll(raw: SDL_Point) -> Pointfn new(x: i32, y: i32) -> Pointfn offset(&self, x: i32, y: i32) -> Pointfn xy(&self) -> (i32, i32)fn x(&self) -> i32fn y(&self) -> i32impl From<(i32, i32)> for Pointimpl Into<(i32, i32)> for Pointimpl Hash for Pointfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Debug for Pointimpl PartialEq for Pointimpl Eq for Pointimpl Clone for Pointfn clone(&self) -> Pointfn clone_from(&mut self, source: &Self)impl Copy for Point
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).
Search functions by type signature (e.g.
vec -> usize)